// Cleanup Contact Sheet.jsx
// Version 1.0
// Modified 04-27-07, Keith Gilbert (www.gilbertconsulting.com)
//
// This script is intended to run on a file created by Adobe's "Create InDesign Contact Sheet" script in Adobe Bridge.
//
// This script will do the following:
//	Remove all empty Graphic Frames and Text frames from all pages
// 	For each Graphic Frame on each page, 
//		Center the graphic in the frame
//		Fit the frame to the graphic
//	Position the top of each caption even with the bottom of each graphic frame
//
// First, check to see whether any InDesign documents are open.
// If no documents are open, display an error message.
if (app.documents.length > 0) {
	myDocument = app.activeDocument;

	// Now look for graphic frames
	for (var i = 0; myDocument.pages.length > i; i++){ // for each page in the document...
		var currentPage = myDocument.pages.item(i);
		
		// search for empty frames on the page, and delete them
		with (currentPage.rectangles) { // on the current page...
    			for (var n = 0; n < length; n++) { // for each graphic...
				var myGraphicFrame = currentPage.rectangles.item(n);	
				if (myGraphicFrame.graphics.length == 0)	 {
					myGraphicFrame.remove();
					n--;
				}
			}
		}
		with (currentPage.textFrames) { // on the current page...
    			for (var n = 0; n < length; n++) { // for each text frame...
				var myTextFrame = currentPage.textFrames.item(n);	
				if (myTextFrame.contents == "") {
					myTextFrame.remove();
					n--;
				}
			}
		} 
		with (currentPage.rectangles) { // on the current page...
    			for (var n = 0; n < length; n++) { // for each graphic...
				var myGraphicFrame = currentPage.rectangles.item(n);
				// Center the graphic in the frame
				myGraphicFrame.fit(1667591779);
				// Fit the frame to the graphic
				myGraphicFrame.fit(1718906723);
				// Make the stroke .25pt, black
				//myGraphicFrame.strokeColor = "Black";
				//myGraphicFrame.strokeWeight = ".25";
				
				// Memorize the y value of the bottom of the graphic frame
				graphicFrameBottom = myGraphicFrame.geometricBounds[2];
				// Captions are placed on the page in the opposite stacking order of the graphic frames
				var myCaption = currentPage.textFrames.item(length - 1 - n);
				// Memorize the x value of the caption
				captionLeft = myCaption.geometricBounds[1];
				// Move the top edge of the caption to the bottom edge of the graphic frame
				myCaption.move([captionLeft,graphicFrameBottom],undefined);
				// Remove the stroke around the caption
				// myCaption.strokeWeight = "0";
			}
		}
	}
	
}
else {
	//No documents are open, so display an error message.
	alert("No InDesign documents are open. Please open a document and try again.")
}